# Jia Le's Library for Python

## Installation

```
pip3 install jiale
```

## Upgrade Library

```
pip3 install jiale --upgrade
```

## Usage

```
from jiale import *
```

## Get Started
Here's the basic command to get started :
```
1. info()    - The library information.
2. version() - The library current version, release date.
3. index()   - The entire index in this library version.
4. formula() - The math formula in this library version.
5. help()    - The short note for the library.
```
